==> billogram-foundation-3.13.10.tgz: package/modules/components/radio/RadioButtonGroup.js <==
import React, { PropTypes } from 'react';
import ReactDOM from 'react-dom';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import RadioButtonOption from './RadioButtonOption';

import isNullOrEmpty from '../../utils/isNullOrEmpty';
import modulus from '../../utils/modulus';


export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');

    const Option = RadioButtonOption({ block, displayName: `${displayName}Option` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            autoFocus: PropTypes.bool,
            disabled: PropTypes.bool,
            onChange: PropTypes.func,
            optionFilter: PropTypes.func,
            optionMapper: PropTypes.oneOfType([PropTypes.func, PropTypes.oneOf(['default', 'html'])]),
            options: PropTypes.arrayOf(
                PropTypes.shape({
                    disabled: PropTypes.bool,
                    text: PropTypes.node,
                    value: PropTypes.string
                })
            ),
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                autoFocus: false,
                disabled: false,
                onChange: () => {},
                optionFilter: (option) => option,
                optionMapper: 'default',
                options: [],
                value: ''
            };
        },

        componentDidMount() {
            if (this.props.autoFocus) {
                ReactDOM.findDOMNode(this.component).focus();
            }
        },

        onKeyDown(evt) {
            switch (evt.which) {
                case 32: // space
                    // don't scroll on page.
                    evt.stopPropagtion();
                    evt.preventDefault;
                    break;

                case 37: // left arrow
                case 38: // up arrow
                    // don't scroll on page.
                    evt.stopPropagation();
                    evt.preventDefault();

                    this.changeByArrowKey(-1);

                    break;

                case 39: // right arrow
                case 40: // down arrow
                    // don't scroll on page.
                    evt.stopPropagation();
                    evt.preventDefault();

                    this.changeByArrowKey(1);

                    break;

                default:
                    break;
            }
        },

        changeByArrowKey(increment) {
            if (this.props.options.length === 0) {
                return;
            }

            if (this.props.options.every((option) => option.disabled)) {
                return;
            }

            const options = this.props.options.filter((option) => this.props.value === option.value);

            const index = options.length > 0
                ? this.props.options.indexOf(options[0])
                : increment > 0 ? -1 : this.props.options.length;

            const value = this.getNewValue(index, increment);
            if (this.props.value === value) {
                return;
            }

            this.props.onChange(value);
        },

        getNewValue(index, increment) {
            const newIndex = modulus(index + increment, this.props.options.length);
            const newOption = this.props.options[newIndex];

            return newOption.disabled
                ? this.getNewValue(newIndex, increment)
                : newOption.value;
        },

        getOptionMapper() {
            const { optionMapper } = this.props;
            if (typeof optionMapper === 'string') {
                switch (optionMapper) {
                    case 'html':
                        return (option) => {
                            return {
                                ...option,
                                text: (<span dangerouslySetInnerHTML={ { __html: option.text } } />)
                            };
                        };

                    default:
                        return (option) => option;
                }
            }

            return optionMapper;
        },

        renderOption(option) {
            const { disabled, text, value } = option;
            const checked = this.props.value === value;

            return (
                <Option
                    checked={ checked }
                    disabled={ disabled || this.props.disabled }
                    key={ value }
                    onChange={ this.props.onChange }
                    text={ text }
                    value={ value } />
            );
        },

        render() {
            const { disabled, optionFilter } = this.props;
            const optionMapper = this.getOptionMapper();

            return (
                <div
                    className={ block({ disabled }) }
                    onKeyDown={ this.onKeyDown }
                    ref={ (c) => this.component = c }
                    tabIndex={ disabled ? null : '0' }>
                    { [].map.call(this.props.options.filter(optionFilter).map(optionMapper), this.renderOption) }
                </div>
            );
        }

    });

};

==> billogram-foundation-4.4.0.tgz: package/modules/components/radio/RadioButtonGroup.js <==
import React, { PropTypes } from 'react';
import ReactDOM from 'react-dom';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import RadioButtonCustomOption from './option-custom/RadioButtonCustomOption';
import RadioButtonOption from './option-default/RadioButtonOption';

import isNullOrEmpty from '../../utils/isNullOrEmpty';
import modulus from '../../utils/modulus';


export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');

    const CustomOption = RadioButtonCustomOption({ block, displayName: `${displayName}CustomOption` });
    const Option = RadioButtonOption({ block, displayName: `${displayName}Option` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            autoFocus: PropTypes.bool,
            disabled: PropTypes.bool,
            onChange: PropTypes.func,
            optionFilter: PropTypes.func,
            optionMapper: PropTypes.oneOfType([PropTypes.func, PropTypes.oneOf(['default', 'html'])]),
            options: PropTypes.arrayOf(
                PropTypes.shape({
                    disabled: PropTypes.bool,
                    text: PropTypes.node,
                    value: PropTypes.string
                })
            ),
            type: PropTypes.oneOf(['custom', 'default']),
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                autoFocus: false,
                disabled: false,
                onChange: () => {},
                optionFilter: (option) => option,
                optionMapper: 'default',
                options: [],
                type: 'default',
                value: ''
            };
        },

        componentDidMount() {
            if (this.props.autoFocus) {
                ReactDOM.findDOMNode(this.component).focus();
            }
        },

        onKeyDown(evt) {
            switch (evt.which) {
                case 32: // space
                    // don't scroll on page.
                    evt.stopPropagtion();
                    evt.preventDefault;
                    break;

                case 37: // left arrow
                case 38: // up arrow
                    // don't scroll on page.
                    evt.stopPropagation();
                    evt.preventDefault();

                    this.changeByArrowKey(-1);

                    break;

                case 39: // right arrow
                case 40: // down arrow
                    // don't scroll on page.
                    evt.stopPropagation();
                    evt.preventDefault();

                    this.changeByArrowKey(1);

                    break;

                default:
                    break;
            }
        },

        changeByArrowKey(increment) {
            if (this.props.options.length === 0) {
                return;
            }

            if (this.props.options.every((option) => option.disabled)) {
                return;
            }

            const options = this.props.options.filter((option) => this.props.value === option.value);

            const index = options.length > 0
                ? this.props.options.indexOf(options[0])
                : increment > 0 ? -1 : this.props.options.length;

            const value = this.getNewValue(index, increment);
            if (this.props.value === value) {
                return;
            }

            this.props.onChange(value);
        },

        getNewValue(index, increment) {
            const newIndex = modulus(index + increment, this.props.options.length);
            const newOption = this.props.options[newIndex];

            return newOption.disabled
                ? this.getNewValue(newIndex, increment)
                : newOption.value;
        },

        getOptionMapper() {
            const { optionMapper } = this.props;
            if (typeof optionMapper === 'string') {
                switch (optionMapper) {
                    case 'html':
                        return (option) => {
                            return {
                                ...option,
                                text: (<span dangerouslySetInnerHTML={ { __html: option.text } } />)
                            };
                        };

                    default:
                        return (option) => option;
                }
            }

            return optionMapper;
        },

        renderOption(option) {
            const { content, disabled, text, value } = option;
            const checked = this.props.value === value;

            switch (option.type) {
                case 'custom':
                    return (
                        <CustomOption
                            checked={ checked }
                            content={ content }
                            disabled={ disabled || this.props.disabled }
                            key={ value }
                            onChange={ this.props.onChange }
                            value={ value } />
                    );

                default:
                    return (
                        <Option
                            checked={ checked }
                            disabled={ disabled || this.props.disabled }
                            key={ value }
                            onChange={ this.props.onChange }
                            text={ text }
                            value={ value } />
                    );
            }
        },

        render() {
            const { disabled, optionFilter, type } = this.props;
            const optionMapper = this.getOptionMapper();

            return (
                <div
                    className={ block({ disabled, type }) }
                    onKeyDown={ this.onKeyDown }
                    ref={ (c) => this.component = c }
                    tabIndex={ disabled ? null : '0' }>
                    { [].map.call(this.props.options.filter(optionFilter).map(optionMapper), this.renderOption) }
                </div>
            );
        }

    });

};
